@@ -4,7 +4,6 @@
 
 from marionette import Marionette, HTMLElement, Actions, MultiActions
 from marionette_test import MarionetteTestCase, CommonTestCase
-from marionette_touch import MarionetteTouchMixin
 from emulator import Emulator
 from runtests import MarionetteTestRunner
-
+from runtests import MarionetteTestOptions
