@@ -174,7 +174,7 @@ class MarionetteTestRunner(object):
                  es_server=None, rest_server=None, logger=None,
                  testgroup="marionette", noWindow=False, logcat_dir=None,
                  xml_output=None, repeat=0, gecko_path=None, testvars=None,
-                 tree=None, type=None, device=None, symbols_path=None,
+                 tree=None, type=None, device=None, symbols_path=None, timeout=None,
                  **kwargs):
         self.address = address
         self.emulator = emulator
@@ -205,6 +205,7 @@ class MarionetteTestRunner(object):
         self.type = type
         self.device = device
         self.symbols_path = symbols_path
+        self.timeout = timeout
 
         if testvars:
             if not os.path.exists(testvars):
@@ -261,7 +262,8 @@ class MarionetteTestRunner(object):
                                          app=self.app,
                                          bin=self.bin,
                                          profile=self.profile,
-                                         baseurl=self.baseurl)
+                                         baseurl=self.baseurl,
+                                         timeout=self.timeout)
         elif self.address:
             host, port = self.address.split(':')
             if self.emulator:
@@ -272,11 +274,13 @@ class MarionetteTestRunner(object):
                                              baseurl=self.baseurl,
                                              logcat_dir=self.logcat_dir,
                                              gecko_path=self.gecko_path,
-                                             symbols_path=self.symbols_path)
+                                             symbols_path=self.symbols_path,
+                                             timeout=self.timeout)
             else:
                 self.marionette = Marionette(host=host,
                                              port=int(port),
-                                             baseurl=self.baseurl)
+                                             baseurl=self.baseurl,
+                                             timeout=self.timeout)
         elif self.emulator:
             self.marionette = Marionette.getMarionetteOrExit(
                                          emulator=self.emulator,
@@ -288,7 +292,8 @@ class MarionetteTestRunner(object):
                                          noWindow=self.noWindow,
                                          logcat_dir=self.logcat_dir,
                                          gecko_path=self.gecko_path,
-                                         symbols_path=self.symbols_path)
+                                         symbols_path=self.symbols_path,
+                                         timeout=self.timeout)
         else:
             raise Exception("must specify binary, address or emulator")
 
@@ -632,6 +637,10 @@ class MarionetteTestOptions(OptionParser):
                         dest='symbols_path',
                         action='store',
                         help='absolute path to directory containing breakpad symbols, or the url of a zip file containing symbols')
+        self.add_option('--timeout',
+                        dest='timeout',
+                        type=int,
+                        help='if a --timeout value is given, it will set the default page load timeout, search timeout and script timeout to the given value. If not passed in, it will use the default values of 30000ms for page load, 0ms for search timeout and 10ms for script timeout')
 
     def verify_usage(self, options, tests):
         if not tests:
